const { spawn } = require('child_process');
const path = require('path');
const AutomatedAnswer = require('../models/automatedAnswer');
const Question = require('../models/question');

/**
 * @Method - POST
 * @param {*} question_id - ID of the question to create automated answer for
 * @returns Whether the automated answer request created or not
 */
exports.requestAutomatedAnswer = async (req, res, next) => {
  const { question_id } = req.body;
  try {
    const question = await Question.findById(question_id);
    if (!question) {
      return res
        .status(404)
        .json({ message: 'No question found for this id, Please try again with another question' });
    }
    let autoAnswer;
    autoAnswer = await AutomatedAnswer.findOne({ question: question_id });

    if (autoAnswer) {
      return res
        .status(303)
        .json({ message: 'Automated answer is already generated', automatedanswer: autoAnswer });
    }

    res.status(201).json({ message: 'Automated answer requested! Please wait for few seconds' });
    autoAnswer = await AutomatedAnswer.create({ question: question._id, loading: true });
    spawn('python', [
      path.join(__dirname, '..', 'python', 'auto-answer', 'scrapper.py'),
      question.title,
      question.tags,
      autoAnswer._id
    ]);
  } catch (err) {
    next(err);
  }
};

/**
 *
 * @Method - GET
 * @qid {*} - question id
 * @returns the automated answer for the question(qid) if there is one
 */
exports.getAutomatedAnswer = async (req, res, next) => {
  const { qid } = req.params;
  console.log('answer is here' + qid);
  try {
    const answer = await AutomatedAnswer.findOne({ question: qid });
    if (!answer) {
      return res.status(404).json({ message: 'No automated answer found for this question' });
    }
    return res.status(200).json({
      message: 'Automated answer found',
      automatedanswer: answer
    });
  } catch (err) {
    next(err);
  }
};
