import json
from search_engine_parser import GoogleSearch
import re
import requests
import random


class Medium:
    def __init__(self, title, tags):
        self.title = title
        self.tags = tags

    def getApiKey(self):
        """
        Returns an API key for retrieve json data
        """
        api_keys = [
            "2rk1eg4sexdnp5umrwtwbtwd2insqvgzvejooqrn",
            "yit6ytfcs3ziawdgasfd3bgkbf4tef1m2nzdxvnz",
            "mpawymyrc6derrwmgodowfsaabtuoes4iiwintd7",
        ]
        return random.choice(api_keys)

    def google(self, query):
        """
        Use a query to search using google search enging
        """
        search_args = (query, 1)
        gsearch = GoogleSearch()
        gresults = gsearch.search(*search_args)
        return gresults["links"]

    def getValidUrls(self, links):
        """
        Validate and filter out the urls.
        Returns the urls that contain medium.com in it as a list
        """
        validUrls = []
        for i in links:
            if "medium.com" in i:
                uriTrimmed = re.match(r"^.*?\&sa=", i[29:]).group(0)
                ur = uriTrimmed.replace("&sa=", "")
                validUrls.append(ur)
        return validUrls

    def getValidSets(self, validUrls):
        """
        Extract usernames and article id's from article url
        pass a list of urls => returns objects list that contain usernam and article id
        """
        validSets = []
        for url in validUrls:
            try:
                vset = {}
                print(url)
                username = re.search(r"https://medium.com/([^/?]+)", url).group(1)
                tag = re.search(r"https://medium.com/([^/?]+)/([^/?]+)", url).group(2)
                vset["username"] = username
                vset["tag"] = tag
                validSets.append(vset)
            except Exception as e:
                print(e)
                continue
        return validSets

    def getBlogs(self, username, tag):
        """
        Get the content of the article
        """
        blog = {}
        try:
            response = requests.get(
                f"https://api.rss2json.com/v1/api.json?rss_url=https%3A%2F%2Fmedium.com%2Ffeed%2F{username}&api_key={self.getApiKey()}"
            )
            if response.status_code == 200:
                res = response.json()
                for item in res["items"]:
                    if tag in item["link"]:
                        blog = item
        except Exception as e:
            print(e)
        return blog

    def getMediumArticles(self):
        """
        return a list of articles and/or resources
        """
        links = self.google(f"site:medium.com {self.title} after:2020-01-01")
        validUrls = self.getValidUrls(links)
        validSets = self.getValidSets(validUrls)
        blogs = []
        for validset in validSets:
            blog = self.getBlogs(validset["username"], validset["tag"])
            if bool(blog):
                blogs.append(blog)
        return {"blogs": blogs, "resources": validUrls}
